#ifndef PYTHONIC_OPERATOR_IFLOORDIV__HPP
#define PYTHONIC_OPERATOR_IFLOORDIV__HPP

#include "pythonic/include/operator_/__ifloordiv__.hpp"
#include "pythonic/operator_/ifloordiv.hpp"

#endif
